import numpy as nm
from porodyn_engine import incremental_algorithm, fc_fce, mat_fce, def_problem


def define():
    params = {
        'mesh_file': 'rect_1x10.vtk',
        'dim': 2,               # problem dimension
        'dt': 0.005,            # time step
        't_end': 0.5,           # end time
        'force': 12e6,          # applied force
        'save_step': True,      # save results in each time step?
        'init_mode': True,      # calculate initial state?
        'mat_store_elem': 5,    # element for which material data are stored
        'u_store_node': 20,     # node for which displacement is stored
        'p_store_node': 0,      # node for which pressure is stored
    }

    material_params = {
        'param': {
            'B': nm.eye(params['dim']),
            'g': 9.81,      # gravitational acceleration
        },
        'solid': {
            'Phi': 0.58,    # volume fraction
            'lam': 29e6,    # Lame coefficient
            'mu': 7e6,      # Lame coefficient
            'rho': 2700,    # density
        },
        'fluid': {
            'kappa': 1e-1,  # permeability parameter
            'beta': 0.8,    # permeability parameter
            'rho': 1000,    # density
            'Kf': 2.2e10,   # bulk modulus
        },
    }

    regions = {
        'Omega': 'all',
        'Left': ('vertices in (x < 0.001)', 'facet'),
        'Right': ('vertices in (x > 0.999)', 'facet'),
        'Bottom': ('vertices in (y < 0.001)', 'facet'),
        'Top': ('vertices in (y > 9.999)', 'facet'),
        'ForceRegion': ('copy r.Top', 'facet'),
    }

    ebcs = {
        'Fixed_Left_u': ('Left', {'u.0': 0.0}),
        'Fixed_Right_u': ('Right', {'u.0': 0.0}),
        'Fixed_Bottom_u': ('Bottom', {'u.1': 0.0}),
        'Fixed_Top_p': ('Top', {'p.0': 0.0}),
    }

    ###############################################

    options = {
        'output_dir': 'output',
        'parametric_hook': 'incremental_algorithm',
    }

    filename_mesh = params['mesh_file']

    materials, functions, fields, variables, equations, solvers = \
        def_problem(params['dt'], params['force'])

    return locals()
